@@ -15,6 +15,7 @@ __all__ = [  # noqa
     "integrations",
     # From sentry_sdk.api
     "init",
+    "add_attachment",
     "add_breadcrumb",
     "capture_event",
     "capture_exception",
@@ -46,6 +47,8 @@ __all__ = [  # noqa
     "trace",
     "monitor",
     "logger",
+    "start_session",
+    "end_session",
 ]
 
 # Initialize the debug support after everything is loaded
